==> openshift-model-config-6.6.2-sources.jar: io/fabric8/openshift/api/model/config/v1/APIServerSpecFluent.java <==
package io.fabric8.openshift.api.model.config.v1;

import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.Integer;
import java.util.Collection;
import java.lang.Object;
import java.util.Map;

 /**
  * Generated
  */
public interface APIServerSpecFluent<A extends APIServerSpecFluent<A>> extends Fluent<A>{
  public A addToAdditionalCORSAllowedOrigins(Integer index,String item);
  public A setToAdditionalCORSAllowedOrigins(Integer index,String item);
  public A addToAdditionalCORSAllowedOrigins(java.lang.String... items);
  public A addAllToAdditionalCORSAllowedOrigins(Collection<String> items);
  public A removeFromAdditionalCORSAllowedOrigins(java.lang.String... items);
  public A removeAllFromAdditionalCORSAllowedOrigins(Collection<String> items);
  public List<String> getAdditionalCORSAllowedOrigins();
  public String getAdditionalCORSAllowedOrigin(Integer index);
  public String getFirstAdditionalCORSAllowedOrigin();
  public String getLastAdditionalCORSAllowedOrigin();
  public String getMatchingAdditionalCORSAllowedOrigin(Predicate<String> predicate);
  public Boolean hasMatchingAdditionalCORSAllowedOrigin(Predicate<String> predicate);
  public A withAdditionalCORSAllowedOrigins(List<String> additionalCORSAllowedOrigins);
  public A withAdditionalCORSAllowedOrigins(java.lang.String... additionalCORSAllowedOrigins);
  public Boolean hasAdditionalCORSAllowedOrigins();
  
  /**
   * This method has been deprecated, please use method buildAudit instead.
   * @return The buildable object.
   */
  @Deprecated
  public Audit getAudit();
  public Audit buildAudit();
  public A withAudit(Audit audit);
  public Boolean hasAudit();
  public APIServerSpecFluent.AuditNested<A> withNewAudit();
  public APIServerSpecFluent.AuditNested<A> withNewAuditLike(Audit item);
  public APIServerSpecFluent.AuditNested<A> editAudit();
  public APIServerSpecFluent.AuditNested<A> editOrNewAudit();
  public APIServerSpecFluent.AuditNested<A> editOrNewAuditLike(Audit item);
  
  /**
   * This method has been deprecated, please use method buildClientCA instead.
   * @return The buildable object.
   */
  @Deprecated
  public ConfigMapNameReference getClientCA();
  public ConfigMapNameReference buildClientCA();
  public A withClientCA(ConfigMapNameReference clientCA);
  public Boolean hasClientCA();
  public A withNewClientCA(String name);
  public APIServerSpecFluent.ClientCANested<A> withNewClientCA();
  public APIServerSpecFluent.ClientCANested<A> withNewClientCALike(ConfigMapNameReference item);
  public APIServerSpecFluent.ClientCANested<A> editClientCA();
  public APIServerSpecFluent.ClientCANested<A> editOrNewClientCA();
  public APIServerSpecFluent.ClientCANested<A> editOrNewClientCALike(ConfigMapNameReference item);
  
  /**
   * This method has been deprecated, please use method buildEncryption instead.
   * @return The buildable object.
   */
  @Deprecated
  public APIServerEncryption getEncryption();
  public APIServerEncryption buildEncryption();
  public A withEncryption(APIServerEncryption encryption);
  public Boolean hasEncryption();
  public A withNewEncryption(String type);
  public APIServerSpecFluent.EncryptionNested<A> withNewEncryption();
  public APIServerSpecFluent.EncryptionNested<A> withNewEncryptionLike(APIServerEncryption item);
  public APIServerSpecFluent.EncryptionNested<A> editEncryption();
  public APIServerSpecFluent.EncryptionNested<A> editOrNewEncryption();
  public APIServerSpecFluent.EncryptionNested<A> editOrNewEncryptionLike(APIServerEncryption item);
  
  /**
   * This method has been deprecated, please use method buildServingCerts instead.
   * @return The buildable object.
   */
  @Deprecated
  public APIServerServingCerts getServingCerts();
  public APIServerServingCerts buildServingCerts();
  public A withServingCerts(APIServerServingCerts servingCerts);
  public Boolean hasServingCerts();
  public APIServerSpecFluent.ServingCertsNested<A> withNewServingCerts();
  public APIServerSpecFluent.ServingCertsNested<A> withNewServingCertsLike(APIServerServingCerts item);
  public APIServerSpecFluent.ServingCertsNested<A> editServingCerts();
  public APIServerSpecFluent.ServingCertsNested<A> editOrNewServingCerts();
  public APIServerSpecFluent.ServingCertsNested<A> editOrNewServingCertsLike(APIServerServingCerts item);
  
  /**
   * This method has been deprecated, please use method buildTlsSecurityProfile instead.
   * @return The buildable object.
   */
  @Deprecated
  public TLSSecurityProfile getTlsSecurityProfile();
  public TLSSecurityProfile buildTlsSecurityProfile();
  public A withTlsSecurityProfile(TLSSecurityProfile tlsSecurityProfile);
  public Boolean hasTlsSecurityProfile();
  public APIServerSpecFluent.TlsSecurityProfileNested<A> withNewTlsSecurityProfile();
  public APIServerSpecFluent.TlsSecurityProfileNested<A> withNewTlsSecurityProfileLike(TLSSecurityProfile item);
  public APIServerSpecFluent.TlsSecurityProfileNested<A> editTlsSecurityProfile();
  public APIServerSpecFluent.TlsSecurityProfileNested<A> editOrNewTlsSecurityProfile();
  public APIServerSpecFluent.TlsSecurityProfileNested<A> editOrNewTlsSecurityProfileLike(TLSSecurityProfile item);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface AuditNested<N> extends Nested<N>,AuditFluent<APIServerSpecFluent.AuditNested<N>>{
    public N and();
    public N endAudit();
    
  }
  public interface ClientCANested<N> extends Nested<N>,ConfigMapNameReferenceFluent<APIServerSpecFluent.ClientCANested<N>>{
    public N and();
    public N endClientCA();
    
  }
  public interface EncryptionNested<N> extends Nested<N>,APIServerEncryptionFluent<APIServerSpecFluent.EncryptionNested<N>>{
    public N and();
    public N endEncryption();
    
  }
  public interface ServingCertsNested<N> extends Nested<N>,APIServerServingCertsFluent<APIServerSpecFluent.ServingCertsNested<N>>{
    public N and();
    public N endServingCerts();
    
  }
  public interface TlsSecurityProfileNested<N> extends Nested<N>,TLSSecurityProfileFluent<APIServerSpecFluent.TlsSecurityProfileNested<N>>{
    public N and();
    public N endTlsSecurityProfile();
    
  }
  
}

==> openshift-model-config-6.7.2-sources.jar: io/fabric8/openshift/api/model/config/v1/APIServerSpecFluent.java <==
package io.fabric8.openshift.api.model.config.v1;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.util.Collection;
import java.lang.Object;
import java.util.Map;

 /**
  * Generated
  */
public interface APIServerSpecFluent<A extends APIServerSpecFluent<A>> extends Fluent<A>{
  public A addToAdditionalCORSAllowedOrigins(int index,String item);
  public A setToAdditionalCORSAllowedOrigins(int index,String item);
  public A addToAdditionalCORSAllowedOrigins(java.lang.String... items);
  public A addAllToAdditionalCORSAllowedOrigins(Collection<String> items);
  public A removeFromAdditionalCORSAllowedOrigins(java.lang.String... items);
  public A removeAllFromAdditionalCORSAllowedOrigins(Collection<String> items);
  public List<String> getAdditionalCORSAllowedOrigins();
  public String getAdditionalCORSAllowedOrigin(int index);
  public String getFirstAdditionalCORSAllowedOrigin();
  public String getLastAdditionalCORSAllowedOrigin();
  public String getMatchingAdditionalCORSAllowedOrigin(Predicate<String> predicate);
  public Boolean hasMatchingAdditionalCORSAllowedOrigin(Predicate<String> predicate);
  public A withAdditionalCORSAllowedOrigins(List<String> additionalCORSAllowedOrigins);
  public A withAdditionalCORSAllowedOrigins(java.lang.String... additionalCORSAllowedOrigins);
  public Boolean hasAdditionalCORSAllowedOrigins();
  
  /**
   * This method has been deprecated, please use method buildAudit instead.
   * @return The buildable object.
   */
  @Deprecated
  public Audit getAudit();
  public Audit buildAudit();
  public A withAudit(Audit audit);
  public Boolean hasAudit();
  public APIServerSpecFluent.AuditNested<A> withNewAudit();
  public APIServerSpecFluent.AuditNested<A> withNewAuditLike(Audit item);
  public APIServerSpecFluent.AuditNested<A> editAudit();
  public APIServerSpecFluent.AuditNested<A> editOrNewAudit();
  public APIServerSpecFluent.AuditNested<A> editOrNewAuditLike(Audit item);
  
  /**
   * This method has been deprecated, please use method buildClientCA instead.
   * @return The buildable object.
   */
  @Deprecated
  public ConfigMapNameReference getClientCA();
  public ConfigMapNameReference buildClientCA();
  public A withClientCA(ConfigMapNameReference clientCA);
  public Boolean hasClientCA();
  public A withNewClientCA(String name);
  public APIServerSpecFluent.ClientCANested<A> withNewClientCA();
  public APIServerSpecFluent.ClientCANested<A> withNewClientCALike(ConfigMapNameReference item);
  public APIServerSpecFluent.ClientCANested<A> editClientCA();
  public APIServerSpecFluent.ClientCANested<A> editOrNewClientCA();
  public APIServerSpecFluent.ClientCANested<A> editOrNewClientCALike(ConfigMapNameReference item);
  
  /**
   * This method has been deprecated, please use method buildEncryption instead.
   * @return The buildable object.
   */
  @Deprecated
  public APIServerEncryption getEncryption();
  public APIServerEncryption buildEncryption();
  public A withEncryption(APIServerEncryption encryption);
  public Boolean hasEncryption();
  public A withNewEncryption(String type);
  public APIServerSpecFluent.EncryptionNested<A> withNewEncryption();
  public APIServerSpecFluent.EncryptionNested<A> withNewEncryptionLike(APIServerEncryption item);
  public APIServerSpecFluent.EncryptionNested<A> editEncryption();
  public APIServerSpecFluent.EncryptionNested<A> editOrNewEncryption();
  public APIServerSpecFluent.EncryptionNested<A> editOrNewEncryptionLike(APIServerEncryption item);
  
  /**
   * This method has been deprecated, please use method buildServingCerts instead.
   * @return The buildable object.
   */
  @Deprecated
  public APIServerServingCerts getServingCerts();
  public APIServerServingCerts buildServingCerts();
  public A withServingCerts(APIServerServingCerts servingCerts);
  public Boolean hasServingCerts();
  public APIServerSpecFluent.ServingCertsNested<A> withNewServingCerts();
  public APIServerSpecFluent.ServingCertsNested<A> withNewServingCertsLike(APIServerServingCerts item);
  public APIServerSpecFluent.ServingCertsNested<A> editServingCerts();
  public APIServerSpecFluent.ServingCertsNested<A> editOrNewServingCerts();
  public APIServerSpecFluent.ServingCertsNested<A> editOrNewServingCertsLike(APIServerServingCerts item);
  
  /**
   * This method has been deprecated, please use method buildTlsSecurityProfile instead.
   * @return The buildable object.
   */
  @Deprecated
  public TLSSecurityProfile getTlsSecurityProfile();
  public TLSSecurityProfile buildTlsSecurityProfile();
  public A withTlsSecurityProfile(TLSSecurityProfile tlsSecurityProfile);
  public Boolean hasTlsSecurityProfile();
  public APIServerSpecFluent.TlsSecurityProfileNested<A> withNewTlsSecurityProfile();
  public APIServerSpecFluent.TlsSecurityProfileNested<A> withNewTlsSecurityProfileLike(TLSSecurityProfile item);
  public APIServerSpecFluent.TlsSecurityProfileNested<A> editTlsSecurityProfile();
  public APIServerSpecFluent.TlsSecurityProfileNested<A> editOrNewTlsSecurityProfile();
  public APIServerSpecFluent.TlsSecurityProfileNested<A> editOrNewTlsSecurityProfileLike(TLSSecurityProfile item);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface AuditNested<N> extends Nested<N>,AuditFluent<APIServerSpecFluent.AuditNested<N>>{
    public N and();
    public N endAudit();
    
  }
  public interface ClientCANested<N> extends Nested<N>,ConfigMapNameReferenceFluent<APIServerSpecFluent.ClientCANested<N>>{
    public N and();
    public N endClientCA();
    
  }
  public interface EncryptionNested<N> extends Nested<N>,APIServerEncryptionFluent<APIServerSpecFluent.EncryptionNested<N>>{
    public N and();
    public N endEncryption();
    
  }
  public interface ServingCertsNested<N> extends Nested<N>,APIServerServingCertsFluent<APIServerSpecFluent.ServingCertsNested<N>>{
    public N and();
    public N endServingCerts();
    
  }
  public interface TlsSecurityProfileNested<N> extends Nested<N>,TLSSecurityProfileFluent<APIServerSpecFluent.TlsSecurityProfileNested<N>>{
    public N and();
    public N endTlsSecurityProfile();
    
  }
  
}
